Package: release.debian.org
Severity: normal
User: release.debian....@packages.debian.org
Usertags: opu

Hi,

This is a follow up on one email thread from <debian-release> list:
  http://lists.debian.org/debian-release/2012/05/msg00182.html

Please apply the attached patch to php-mdb2 package version 2.5.0b2-1
from Debian 6.0 (squeeze) in a future point release (6.0.8 or later).

Cheers

-- System Information:
Debian Release: 7.0
  APT prefers stable
  APT policy: (500, 'stable'), (1, 'experimental')
Architecture: i386 (i686)

Kernel: Linux 3.2.0-4-686-pae (SMP w/2 CPU cores)
Locale: LANG=en_US.utf8, LC_CTYPE=en_US.utf8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
--- /usr/share/php/MDB2.php_2.5.0b2-1	2009-04-25 18:23:22.000000000 +0300
+++ /usr/share/php/MDB2.php	2012-05-03 18:14:11.451133868 +0300
@@ -390,7 +390,7 @@
             return $err;
         }
 
-        $db =& new $class_name();
+        $db = new $class_name();
         $db->setDSN($dsninfo);
         $err = MDB2::setOptions($db, $options);
         if (PEAR::isError($err)) {
@@ -2596,7 +2596,7 @@
     }
 
     // }}}
     // {{{ function &_wrapResult($result, $types = array(), $result_class = true, $result_wrap_class = false, $limit = null, $offset = null)
 
     /**
      * wrap a result set into the correct class
@@ -2613,13 +2613,13 @@
      *
      * @access  protected
      */
-    function &_wrapResult($result, $types = array(), $result_class = true,
+    function &_wrapResult($result_resource, $types = array(), $result_class = true,
         $result_wrap_class = false, $limit = null, $offset = null)
     {
         if ($types === true) {
             if ($this->supports('result_introspection')) {
                 $this->loadModule('Reverse', null, true);
-                $tableInfo = $this->reverse->tableInfo($result);
+                $tableInfo = $this->reverse->tableInfo($result_resource);
                 if (PEAR::isError($tableInfo)) {
                     return $tableInfo;
                 }
@@ -2644,7 +2644,7 @@
                     'result class does not exist '.$class_name, __FUNCTION__);
                 return $err;
             }
-            $result =& new $class_name($this, $result, $limit, $offset);
+            $result = new $class_name($this, $result_resource, $limit, $offset);
             if (!MDB2::isResultCommon($result)) {
                 $err =& $this->raiseError(MDB2_ERROR_NOT_FOUND, null, null,
                     'result class is not extended from MDB2_Result_Common', __FUNCTION__);
@@ -2667,7 +2667,7 @@
                     'result wrap class does not exist '.$result_wrap_class, __FUNCTION__);
                 return $err;
             }
-            $result = new $result_wrap_class($result, $this->fetchmode);
+            $result = new $result_wrap_class($result_resource, $this->fetchmode);
         }
         return $result;
     }
@@ -2596,7 +2596,7 @@
 
     // }}}
-    // {{{ function &_wrapResult($result, $types = array(), $result_class = true, $result_wrap_class = false, $limit = null, $offset = null)
+    // {{{ function &_wrapResult($result_resource, $types = array(), $result_class = true, $result_wrap_class = false, $limit = null, $offset = null)
 
     /**

Reply via email to